#!/bin/bash

#Sort Dump files
sort -T /DATA -k1,1 All_KolmMale.Jelly_NoBloom_k31count_dump_nohigh2 > All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.sorted &
sort -T /DATA -k1,1 KolmFemale_All.Jelly_NoBloom_k31count_dump_nohigh2 > KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.sorted &

wait

#Use python script to add reverse compliments of Kmers to sorted dump files
python Add_reverse_comp.py -d All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.sorted -o All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.revcomp &
python Add_reverse_comp.py -d KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.sorted -o KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.revcomp &

wait

rm All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.sorted
rm KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.sorted

wait

#Split Male reverse compliment dump file for parallelisation
split --number=l/3 All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.revcomp

wait

mv xaa All_KolmMale_pt1.Jelly_NoBloom_k31dump_nohigh2.revcomp
mv xab All_KolmMale_pt2.Jelly_NoBloom_k31dump_nohigh2.revcomp
mv xac All_KolmMale_pt3.Jelly_NoBloom_k31dump_nohigh2.revcomp

wait

########################################################
## Now run make table script comparing male to female ##
########################################################

python Make_Table_of_Coverages.py -m All_KolmMale_pt1.Jelly_NoBloom_k31dump_nohigh2.revcomp -f KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.revcomp -g 4 -o Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt1.table -l Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt1.log  > pt1_nohigh2_foo

wait

python Make_Table_of_Coverages.py -m All_KolmMale_pt2.Jelly_NoBloom_k31dump_nohigh2.revcomp -f KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.revcomp -g 4 -o Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt2.table -l Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt2.log  > pt2_nohigh2_foo

wait

python Make_Table_of_Coverages.py -m All_KolmMale_pt3.Jelly_NoBloom_k31dump_nohigh2.revcomp -f KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.revcomp -g 4 -o Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt3.table -l Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt3.log > pt3_nohigh2_foo

wait

#Cat Tables together (these contain kmers found in both males and females, and unique to males, but does not have those unique to females)
cat Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt1.table Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt2.table Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_pt3.table > Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_ALL.table

# Grep unqiue male 
grep " 0" Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_ALL.table > grepMaleUni_nohigh2.ALL

split --number=l/3  KolmFemale_All.Jelly_NoBloom_k31dump_nohigh2.revcomp

wait

#Split female reverse compliment dump file for parallelisation
mv xaa  KolmFemale_All_pt1.Jelly_NoBloom_k31dump_nohigh2.revcomp
mv xab  KolmFemale_All_pt2.Jelly_NoBloom_k31dump_nohigh2.revcomp
mv xac  KolmFemale_All_pt3.Jelly_NoBloom_k31dump_nohigh2.revcomp

wait

########################################################
## Now run make table script comparing female to male ##
########################################################

python Make_Table_of_Coverages.py -m  KolmFemale_All_pt1.Jelly_NoBloom_k31dump_nohigh2.revcomp -f All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.revcomp -g 4 -o Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt1.table -l Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt1.log  > fem.pt1_nohigh2_foo

python Make_Table_of_Coverages.py -m  KolmFemale_All_pt2.Jelly_NoBloom_k31dump_nohigh2.revcomp -f All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.revcomp -g 4 -o Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt2.table -l Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt2.log  > fem.pt2_nohigh2_foo

python Make_Table_of_Coverages.py -m  KolmFemale_All_pt3.Jelly_NoBloom_k31dump_nohigh2.revcomp -f All_KolmMale.Jelly_NoBloom_k31dump_nohigh2.revcomp -g 4 -o Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt3.table -l Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt3.log  > fem.pt3_nohigh2_foo

wait

#Cat Tables together (these contain kmers found in both males and females, and those unique to females)
cat Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt1.table Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt2.table Shared_FemUni_Jelly_NoBloom_k31_nohigh2_pt3.table > Shared_FemUni_Jelly_NoBloom_k31_nohigh2_ALL.table

#Switch columns in female table
awk ' { t = $2; $2 = $3; $3 = t; print; } ' Shared_FemUni_Jelly_NoBloom_k31_nohigh2_ALL.table > Shared_FemUni_Jelly_NoBloom_k31_nohigh2_ALL.table_switch

#Grep female unique
grep " 0" Shared_FemUni_Jelly_NoBloom_k31_nohigh2_ALL.table_switch > grepFemUni_nohigh2.ALL

wait

#Cat together male table with female unique kmers, (this now contains kmers found in both males and females, those unique to males, and those unique to females)
cat Shared_MaleUni_Jelly_NoBloom_k31_nohigh2_ALL.table grepFemUni_nohigh2.ALL > Shared_MF_Uni_Jelly_NoBloom_k31_nohigh2_ALL.table

